# ecnunetwork

[![python version](https://img.shields.io/pypi/pyversions/ecnunetwork.svg?logo=python&logoColor=white)](https://pypi.org/project/ecnunetwork)
[![PyPI](https://img.shields.io/pypi/v/ecnunetwork.svg)](https://pypi.org/project/ecnunetwork)
[![Build Status](https://travis-ci.com/njzjz/ecnunetwork.svg?branch=master)](https://travis-ci.com/njzjz/ecnunetwork)
[![Build status](https://ci.appveyor.com/api/projects/status/rr6dvs3wvvkg33dd?svg=true)](https://ci.appveyor.com/project/jzzeng/ecnunetwork)
[![Coverage Status](https://coveralls.io/repos/github/njzjz/ecnunetwork/badge.svg?branch=master)](https://coveralls.io/github/njzjz/ecnunetwork?branch=master)
[![codecov](https://codecov.io/gh/njzjz/ecnunetwork/branch/master/graph/badge.svg)](https://codecov.io/gh/njzjz/ecnunetwork)

A script to connect to the Internet at [East China Normal University](http://english.ecnu.edu.cn).

**Author**: Jinzhe Zeng

**Email**: jzzeng@stu.ecnu.edu.cn

## Installation

Although you cannot connect to IPv4 servers before logining, IPv6 servers are still available, so you can use pip to install.

```sh
pip install ecnunetwork
```

## Usage
```sh
network
```
